# Build a Singularity image, a Docker container and upload your project and images to the OSSR

This code snippet will:

 - Builds a Docker container during the CI process.
 - Builds a Singularity image during the CI process.
 - Makes available the created artifacts (both images) to be used in the next CI stages.
 - Uploads the next released version of the current project, together with both images, to the ESCAPE-OSSR 
 (The ESCAPE2020 Zenodo community).

Have a look before to the examples in this same directory.

```yaml
stages:
 - build_container
 - deploy

build_singularity_image:
  stage: build
  image: singularityware/singularity:gitlab-2.6
  script:
    # You should have added before your Singularity recipe in a Singularity dir
    - singularity build $IMAGE_NAME.simg Singularity/Singularity

    - mkdir -p build && cp Singularity/*.simg build
    - mkdir -p build && cp Singularity/Singularity* build
  artifacts:
    paths:
      - build/Singularity.simg
      - build/Singularity
  only:
    - tags

build_docker_image:
  stage: build
  image: docker:19.03.12
  services:
    - docker:19.03.12-dind
  before_script:
    - cat /etc/os-release  # "Alpine Linux v3.12"
    - apk add git
    - export LAST_RELEASE=`git ls-remote --tags --refs --sort="v:refname" $CI_PROJECT_URL.git | tail -n1 | sed 's/.*\///'`
    - echo $LAST_RELEASE
  script:
    - cd Docker
    - docker login -u $CI_REGISTRY_USER -p $CI_REGISTRY_PASSWORD $CI_REGISTRY
    - docker build -t $CI_REGISTRY_IMAGE:$LAST_RELEASE .
    - docker push $CI_REGISTRY_IMAGE:$LAST_RELEASE

    # Save docker image into a file to be uploaded in next stage
    - docker save -o Docker_image_ESCAPE_template_project_$LAST_RELEASE.tar $CI_REGISTRY_IMAGE:$LAST_RELEASE
    - cd .. && mkdir -p build && cp Docker/*.tar build
    - ls build
  artifacts:
    paths:
      - build/Docker_image_ESCAPE_template_project_*.tar
  only:
    - tags


deploy_zenodo:
  stage: deploy
  image: gitlab-registry.in2p3.fr/escape2020/wp3/eossr:v0.1
  # The `dependencies` key (and field) is added to this stage ONLY because we have created 
  #  in previous stages some artifacts
  dependencies:
    - build_singularity_image
    - build_docker_image
  before_script:
    - test_connection_zenodo --token $ZENODO_TOKEN --sandbox False -p $CI_PROJECT_DIR
  script:
    - mkdir -p build
    - parse_last_release_git.sh $CI_PROJECT_NAME $CI_PROJECT_URL
    - if [[ -f ./codemeta.json ]]; then cp ./codemeta.json ./build; fi
    - ls ./build

    - upload_new_version_deposit -t $ZENODO_TOKEN -s False -i ./build -id $ZENODO_PROJECT_ID
  only:
    - tags
```
